@@ -2,4 +2,4 @@ import os
 import sys
 LED_PATH = os.getcwd()
 sys.path.append(os.path.join(LED_PATH, 'ws2x'))
-from led import LEDSim
\ No newline at end of file
+from ws2x.led import LEDSim
\ No newline at end of file
